/* ʣ̲
 * Copyright (C) 2004 Kagetani Hideto
 */

#ifndef __UI_H__
#define __UI_H__

#include "option.h"
#include <gtk/gtk.h>

BOOL UICheckAbort();
void UISetAbort();
void UIClearAbort();
int UIDispMessage(const char *message, int type);
/* type value */
#define UIDMT_INFORMATION	0
#define UIDMT_ERROR		1
#define UIDMT_QUESTION	2
/* return value */
#define UIDMRET_OK		0
#define UIDMRET_CANCEL	1

extern void UIMeter1Initialize(const char *message);
extern void UIMeter2Initialize(const char *message);
extern void UIMeter1Update(float percentage);
extern void UIMeter2Update(float percentage);
extern void UIDispInfo(const char *message);
extern int UIFileDialog(BOOL bOpen, char *filename, int size, const char *suffix);
extern int UINetDialog(BOOL bServer, char *remote, int size, int *port_number);

extern void UISetWidgetMeter1(GtkWidget *label, GtkWidget *progressbar);
extern void UISetWidgetMeter2(GtkWidget *label, GtkWidget *progressbar);
extern void UISetWidgetInfo(GtkWidget *label);

extern int UISetting(OPTIONS *option);

#endif /* !__UI_H__ */
